var searchData=
[
  ['test_20測試_0',['Test 測試',['../index.html#autotoc_md20',1,'']]],
  ['textdict_1',['TextDict',['../classopencc_1_1_text_dict.html',1,'opencc::TextDict'],['../classopencc_1_1_text_dict.html#a853bbb425460e21199d934b6dc518b97',1,'opencc::TextDict::TextDict()']]],
  ['textdicttestbase_2',['TextDictTestBase',['../classopencc_1_1_text_dict_test_base.html',1,'opencc']]],
  ['third_20party_20library_20第三方庫_3',['Third Party Library 第三方庫',['../index.html#autotoc_md26',1,'']]],
  ['truncateutf8_4',['TruncateUTF8',['../classopencc_1_1_u_t_f8_util.html#ac0500d05548097452c9d5457449d648b',1,'opencc::UTF8Util']]],
  ['typescript_5',['TypeScript',['../index.html#autotoc_md8',1,'']]]
];
